@@ -218,22 +218,34 @@ runMacs = function(nInd,nChr=1, segSites=NULL, inbred=FALSE, species="GENERIC",
     }
     command = paste0(popSize," ",speciesParams,splitI," ",speciesHist,splitJ," -s ")
   }
+  
   if(!is.null(manualGenLen)){
     genLen = manualGenLen
   }
+  
   if(length(genLen)==1){
     genLen = rep(genLen, nChr)
   }
+  
+  # Run MaCS
   macsOut = MaCS(command, segSites, inbred, ploidy, 
                  nThreads, seed)
   dim(macsOut$geno) = NULL # Account for matrix bug in RcppArmadillo
+  
+  # Check if desired number of loci were obtained
   nLoci = sapply(macsOut$genMap,length)
+  isLimited = segSites>0
+  if(any(nLoci[isLimited] != segSites[isLimited])){
+    stop("MaCS did not return enough segSites, use segSites=NULL to return all sites generated by MaCS")
+  }
+  
   genMap = vector("list",nChr)
   for(i in 1:nChr){
     genMap[[i]] = genLen[i]*c(macsOut$genMap[[i]]-macsOut$genMap[[i]][1])
     names(genMap[[i]]) = paste(i,1:length(genMap[[i]]),sep="_")
   }
   names(genMap) = as.character(1:nChr)
+  
   output = new("MapPop",
                nInd=nInd,
                nChr=nChr,
